<?php

/**
 * Abstract Class for creating meta boxes using CodeStart Framework
 *
 * @since      0.9.0
 * @package    Akd_Framework
 * @subpackage Akd_Framework/includes
 */
abstract class Akd_Framework_Meta {
	private $prefix;
	protected $post_type;
	private $mem_prefix;

	public function __construct( $plugin_name ) {
		$this->prefix = $plugin_name;
		$this->init_meta();
		$this->introduce_tabs();
		$this->admin_init();

	}

	private function pre($data){
		echo '<pre>'; print_r($data);
	}

	/**
	 * Method to get and present the elementor color settings within theme settings tabs
	 */
	private function akd_get_elementor_theme_settings(){
		if (in_array('elementor/elementor.php', apply_filters('active_plugins', get_option('active_plugins')))) {

			// Path to the JSON file
			$font_file_path = plugin_dir_path(__FILE__) . 'class-akd-framework-google-font-list.json';
			// Read the JSON file content
			$json_content = file_get_contents($font_file_path);
			// Decode the JSON string into a PHP array
			$fonts_array = json_decode($json_content, true);

			$active_kit_id = get_option('elementor_active_kit');
			$elementor_global_settings = get_option('_akd_elementor_global');

			if ($active_kit_id) {
				// $elementor_data = json_decode($elementor_global_settings, true);
				$elementor_data = get_post_meta($active_kit_id, '_elementor_page_settings', true);
				
				if($elementor_data){
					$dropdowns_arr = [];
					foreach ($elementor_data['system_typography'] as $key => $typography) {
						$dropdowns_arr[] = array(
							'id'          => 'akd-'.$typography['_id'].'-typography',
							'type'        => 'select',
							'title'       => __($typography['title'], 'wp-whmcs-sync'),
							'chosen'      => true,
							'ajax'        => true,
							'placeholder' => __('Select an option', 'wp-whmcs-sync'),
							'options' 	  => $fonts_array,
							'default' => $typography['typography_font_family']
						);
					}
	
					$font_weight_arr = [];
					foreach ($elementor_data['system_typography'] as $key => $typography) {
						$font_weight_arr[] = array(
							'id'    => 'akd-'.$typography['_id'].'-font-weight',
							'type'  => 'number',
							'title' => __($typography['title'] . ' font weight', 'akd-demo-importer'),
							'default' => isset($typography['typography_font_weight']) ? $typography['typography_font_weight'] : '',
						);
					}
	
					$custom_colors_options = array();
					$custom_colors_default = array();
					$options = array();
					$default_colors = array();
	
					foreach ($elementor_data['system_colors'] as $color_data) {
						$color_id = $color_data['_id'];
						$color_title = ucfirst($color_data['title']); // Capitalize the first letter of the title
						$color_key = str_replace('-', '_', $color_id); // Convert hyphens to underscores for the option key
						
						// Add color options for regular and hovered states
						$options[$color_key] = $color_title;
						// $options[$color_key . '_hovered_state'] = $color_title . ' (hovered state)';
						
						// Add default colors
						$default_colors[$color_key] = $color_data['color'];
						// $default_colors[$color_key . '_hovered_state'] = $color_data['color'];
					}
	
					if (isset($elementor_data['custom_colors'])) {
						foreach ($elementor_data['custom_colors'] as $color_data) {
							$color_id = $color_data['_id'];
							$color_title = ucfirst($color_data['title']); // Capitalize the first letter of the title
							$color_key = 'custom-color-' . $color_id; // Construct the option key based on the color id
							$color = $color_data['color'];
	
							// Add color options for regular and hovered states
							$custom_colors_options[$color_key] = $color_title;
							// $custom_colors_options[$color_key . '-hovered-state'] = $color_title . ' (hovered state)';
	
							// Add default colors
							$custom_colors_default[$color_key] = $color;
							// $custom_colors_default[$color_key . '-hovered-state'] = $color;
						}
					}
	
					$theme_settings = array(
						'title'  => __( 'Theme Settings', 'akd-demo-importer' ),
						'fields' => array(
							array(
								'type'    => 'subheading',
								'content' => __('Global Colors', 'akd-demo-importer'),
							),
							array(
								'id' => 'akd-theme-colors',
								'type' => 'color_group',
								'title' => __('Theme Colors', 'akd-demo-importer'),
								'options' => $options,
								'default' => $default_colors
							),
							// Custom colors
							array(
								'id' => 'akd-custom-colors',
								'type' => 'color_group',
								'title' => __('Custom Colors', 'akd-demo-importer'),
								'options' => $custom_colors_options,
								'default' => $custom_colors_default
							),
							array(
								'type'    => 'subheading',
								'content' => __('Typography', 'akd-demo-importer'),
							),
							$dropdowns_arr[0],
							$font_weight_arr[0],
							$dropdowns_arr[1],
							$font_weight_arr[1],
							$dropdowns_arr[2],
							$font_weight_arr[2],
						),
					);
				} else {
					$theme_settings = array(
						'title'  => __( 'Theme Settings', 'akd-demo-importer' ),
						'fields' => array(
							array(
								'type'    => 'notice',
								'style'   => 'error',
								'content' => __('Please import demo content to make the theme settings enable.', 'akd-demo-importer'),
							),
						),
					);
				}
			} else {
				$theme_settings = array(
					'title'  => __( 'Theme Settings', 'akd-demo-importer' ),
					'fields' => array(
						array(
							'type'    => 'notice',
							'style'   => 'error',
							'content' => __('Please import demo content to make the theme settings enable.', 'akd-demo-importer'),
						),
					),
				);
			}

		} else {
			$theme_settings = array(
				'title'  => __( 'Theme Settings', 'akd-demo-importer' ),
				'fields' => array(
					array(
						'type'    => 'subheading',
						'content' => __('Global Colors', 'akd-demo-importer'),
					),
					array(
						'type'    => 'subheading',
						'content' => __('Typography', 'akd-demo-importer'),
					),
				),
			);
		}

		return $theme_settings;

	}

	/**
	 * Method to create admin options
	 *
	 * @return void
	 */
	private function admin_init(  ){
		$activated_theme = wp_get_theme();
		
		// Create options
		CSF::createOptions(
			'akd-framework-admin-page',
			array(
				'menu_title'         => __( $activated_theme->get('Name') .' Settings', 'akd-demo-importer' ),
				'menu_slug'          => 'akd-framework',
				'framework_title'    => __( $activated_theme->get('Name') .' Options', 'akd-demo-importer' ),
				'menu_position'      => 15,
				'show_search'        => false,
				'show_reset_all'     => false,
				'show_reset_section' => false,
				'ajax_save'          => false,
				// 'menu_icon'          => 'https://ps.w.org/dummy-images/assets/icon-256x256.png?rev=2024916',
			)
		);

		//theme activation
		CSF::createSection(
			'akd-framework-admin-page',
			array(
				'title'  => __( 'Theme Dashboard', 'akd-demo-importer' ),
				'fields' => array(

					array(
						'id'            => 'akd-theme-dashboard',
						'type'          => 'tabbed',
						'title'         => __('Theme Dashboard', 'akd-demo-importer'),
						'class' 		=> 'akd-framework-tabbed',
						'tabs'          => array(
							array(
								'title'     => 'General',
								'icon'      => 'fa fa-cube',
								'fields'    => array(
									array(
										'id'      => 'akd-act-name',
										'type'    => 'text',
										'title'   => __('Full Name *', 'akd-demo-importer'),
										'placeholder' => __('Enter your name.', 'akd-demo-importer'),
										'class' => 'akd-full-name',
										'required' => true
									),
				
									array(
										'id'      => 'akd-act-email',
										'type'    => 'text',
										'title'   => __('Email *', 'akd-demo-importer'),
										'placeholder' => __('Enter your email.', 'akd-demo-importer'),
										'class' => 'akd-email',
										'required' => true
									),
				
									array(
										'id'         => 'akd-act-options',
										'type'       => 'radio',
										'title'      => __('Activation Method', 'akd-demo-importer'),
										'options'    => array(
											'purchase-code' 	  => __('Already have a purchase code', 'akd-demo-importer'),
											'get-purchase-code' => __('Downloaded this theme from Envato Elements', 'akd-demo-importer'),
										),
										'default'    => 'purchase-code',
										'class' => 'akd-act-option'
									),
								)
							),
							array(
								'title'     => __('Plugins', 'akd-demo-importer'),
								'icon'      => 'fa fa-plug',
								'fields'    => array(
									array(
										'type'     => 'callback',
										'function' => array($this, 'akd_required_plugins_callback'),
									),
								)
							),
							array(
								'title'     => __('Demo Data', 'akd-demo-importer'),
								'icon'      => 'fa fa-desktop',
								'fields'    => array(
									array(
										'type'     => 'callback',
										'function' => array($this, 'akd_theme_demo_importer_callback'),
									),
								)
							),

							array(
								'title'     => __('Install Demo', 'akd-demo-importer'),
								'icon'      => 'fa fa-download',
								'fields'    => array(
									array(
										'type'     => 'callback',
										'function' => array($this, 'akd_install_demo_data_callback'),
									),
								)
							),

							$this->akd_get_elementor_theme_settings(),
							
						)
					),
				),
			)
		);

		// CSF::createSection(
		// 	'akd-framework-admin-page',
		// 	array(
		// 		'title'  => __( $activated_theme->get('Name') .' Addons', 'akd-demo-importer' ),
		// 		'fields' => array(
					
		// 		),
		// 	)
		// );

		// CSF::createSection(
		// 	'akd-framework-admin-page',
		// 	array(
		// 		'title'  => __( 'Theme Options', 'akd-demo-importer' ),
		// 		'fields' => array(
					
		// 		),
		// 	)
		// );

	}

	/**
	 * Method to load all required plugins by the theme
	 */
	public function akd_required_plugins_callback() {

		$demo_dir = plugin_dir_path( dirname( __FILE__ ) ) . 'admin/demo';

		$content = '';
		// if(!get_option('_akd_demo_import')){
			// $content .= '
			// 	<div class="akd-required-plugins-wrapper">
			// 		<div class="akd-required-plugins-section">
			// 			<div class="akd-plugin-installation-description">
			// 				<p>'.__('Configure and enable theme-specific plugins. Only select plugins intended for immediate use. Installation of plugins can also be performed through the "Appearance - Install Plugins" menu.', 'akd-demo-importer').'</p>
			// 			</div>
			// 			<div class="akd-required-plugin-info-box">
			// 				<p class="akd-required-plugin-info-box-notice"><b>'.__('Attention!', 'akd-demo-importer').'</b> '.__('Sometimes, the activation of some plugins interferes with the process of other plugins installation. If a plugin is still on the "Activating" stage after 1 minute, just reload the page (by pressing F5) and then switch to the "Plugins" tab; there you should check the required plugins that remained uninstalled and proceed with the installation ("Install &amp; Activate" button below the list of plugins)', 'akd-demo-importer').'</p>
			// 			</div>
			// 		</div>
					
			// 		<div class="akd-install-req-plugins">
			// 			<a class="akd-plugin-inst" href="'.admin_url('themes.php?page=merlin&step=plugins').'"> '.__('Proceed', 'akd-demo-importer').' </a>
			// 		</div>

			// 		<div class="akd-req-plugin-inst-content">

			// 		</div>
			// 	</div>
			// ';

			$merlin = new Merlin;
			$merlin->plugins();
		// } else {
		// 	$content .= '
		// 		<div class="akd_content--transition">
		// 			<svg class="icon icon--plugins" aria-hidden="true" role="img"><use xlink:href="#icon-plugins"></use></svg>
		// 			<h1>'.__('You are up to speed!', 'akd-demo-importer').'</h1>
		// 			<p>'.__('The demo has been imported successfully.', 'akd-demo-importer').'</p>
		// 		</div>

		// 		<div class="akd-view-site-wrapper">
		// 			<a class="akd-view-site" href="#"> '.__('View Site', 'akd-demo-importer').' </a>
		// 		</div>
		// 	';
		// }

		echo $content;
	}

	
	/**
	 * Method to load theme's demo data
	 */
	public function akd_theme_demo_importer_callback(){
		$content = '';
		$demo_dir = plugin_dir_path( dirname( __FILE__ ) ) . 'admin/demo/';
		$screenshot = $demo_dir . 'screenshot.png';
		$layout_number = '';

		if(!get_option('_akd_demo_import')){
			$content .= '
				<div class="akd-required-plugins-section">
					<p class="akd-required-plugin-info-box-notice">'.__('Select your desired demo, and then click "Install" to initiate the installation of the demo data.', 'akd-demo-importer').'</p>
				</div>';

			if ( ! empty( $screenshot ) ) {
				$content .= '<div class="demo-container">';
					$demo_name = basename( dirname( $screenshot ) );
					$screenshot = plugins_url('akd-demo-importer/admin/demo/screenshot.png');
					$activated_theme = wp_get_theme();

					$content .= '
						<div class="demo-item">
							<div class="screenshot-container">
								<img class="screenshot" src="' . $screenshot . '" alt="' . $activated_theme->get_template() . '">
								<div class="overlay"></div>
								<div class="button-container">
									<a class="preview-button" href="https://designingmedia.com/'.$activated_theme->get_template().'" target="_blank">'.__('Preview', 'akd-demo-importer').'</a>
									<a class="proceed-button akd-trigger-import" href="#" >'.__('Install', 'akd-demo-importer').'</a>
								</div>
							</div>
							<div class="layout-name">' . ucfirst($activated_theme->get_template()) . '</div>
						</div>
					';
				$content .= '</div>'; 
			} else {
				$content .= '<span class="akd-demos">'.__('No demos available.', 'akd-demo-importer').'</span>';
			}
		} else {
			$content .= '
				<div class="merlin__content merlin__content--plugins">
					<div class="merlin__content--transition akd_content--transition">
						<svg class="icon icon--plugins" aria-hidden="true" role="img"><use xlink:href="#icon-plugins"></use></svg>
						<h1>'.__('You are up to speed!', 'akd-demo-importer').'</h1>
						<p>'.__('The demo has been imported successfully.', 'akd-demo-importer').'</p>

						<div class="akd-view-site-wrapper">
							<a class="merlin__button akd-view-site" href="#"> '.__('View Site', 'akd-demo-importer').' </a>
						</div>
					</div>
				</div>
			';
		}

		echo $content;
	}

	public function akd_install_demo_data_callback(){
		
		$merlin = new Merlin;
		$merlin->content();

		$content = '';
		$content .= '<div class="akd-demo-import-content">

		</div>';
	}


	/**
	 * Method to create metabox
	 *
	 * @return void
	 */
	private function init_meta() {
		CSF::createMetabox(
			$this->prefix,
			array(
				'title'     => __( $this->meta_title, 'akd-demo-importer' ),
				'post_type' => $this->post_type,
			)
		);
	}

	/**
	 * Method to populate the metabox
	 *
	 * @return void
	 */
	private function introduce_tabs() {
		$tabs = $this->get_fields();
		foreach ( $tabs as $tab ) {
			CSF::createSection( $this->prefix, $tab );
		}
	}
}